==> jbpm-distro-4.0.jar: jbpm-4.0/src/org/jbpm/pvm/internal/type/variable/BlobVariable.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.type.variable;

import org.jbpm.pvm.internal.env.Environment;
import org.jbpm.pvm.internal.lob.Lob;
import org.jbpm.pvm.internal.session.DbSession;
import org.jbpm.pvm.internal.type.Variable;

public class BlobVariable extends Variable {

  private static final long serialVersionUID = 1L;
  
  protected Lob lob = null;

  public boolean isStorable(Object value) {
    if (value==null) return true;
    return (byte[].class.isAssignableFrom(value.getClass()));
  }

  public Object getObject() {
    if (lob==null) return null; 
    return lob.extractBytes();
  }

  public void setObject(Object value) {
    if (this.lob!=null) {
      DbSession dbSession = Environment.getFromCurrent(DbSession.class, false);
      if (dbSession!=null) {
        dbSession.delete(this.lob);
      }
    }
    this.lob = new Lob((byte[])value);
  }
  
  public Lob getLob() {
    return lob;
  }
}

==> jbpm-distro-4.1.jar: jbpm-4.1/src/org/jbpm/pvm/internal/type/variable/BlobVariable.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.type.variable;

import org.jbpm.pvm.internal.env.EnvironmentImpl;
import org.jbpm.pvm.internal.lob.Lob;
import org.jbpm.pvm.internal.session.DbSession;
import org.jbpm.pvm.internal.type.Variable;

public class BlobVariable extends Variable {

  private static final long serialVersionUID = 1L;
  
  protected Lob lob = null;

  public boolean isStorable(Object value) {
    if (value==null) return true;
    return (byte[].class.isAssignableFrom(value.getClass()));
  }

  public Object getObject() {
    if (lob==null) return null; 
    return lob.extractBytes();
  }

  public void setObject(Object value) {
    if (this.lob!=null) {
      DbSession dbSession = EnvironmentImpl.getFromCurrent(DbSession.class, false);
      if (dbSession!=null) {
        dbSession.delete(this.lob);
      }
    }
    this.lob = new Lob((byte[])value);
  }
  
  public Lob getLob() {
    return lob;
  }
}
